#
# spec file for package sleuthkit
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sosuffix 13

Name:           sleuthkit
Version:        4.4.2
Release:        lp150.1.8
Summary:        The Sleuth Kit (TSK): tools for file system and volume forensic analysis
License:        CPL-1.0 and IPL-1.0 and GPL-2.0+
Group:          System/Monitoring
Url:            http://www.sleuthkit.org/
Source0:        https://github.com/%{name}/%{name}/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  libopenssl-devel
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#BuildRequires:  libtool

# libewf - Newer versions are plain BSD (older are BSD with advertising)
BuildRequires:  libewf-devel = 0~20140608

Requires:       file
Requires:       libtsk%sosuffix = %{version}
Requires:       mac-robber
# fiwalk has been incorporated into sleuthkit.  Last standalone version was 0.6.16
Provides:       fiwalk = %{version}
Obsoletes:      fiwalk < %{version}

%description
The Sleuth Kit (TSK) is a collection of UNIX-based command line tools that
allow you to investigate a computer. The current focus of the tools is the
file and volume systems and TSK supports FAT, Ext2/3, NTFS, UFS,
and ISO 9660 file systems

%package        -n libtsk%sosuffix
Summary:        Library for %{name}
Group:          System/Libraries

%description    -n libtsk%sosuffix
The libtsk%sosuffix package contains library for %{name}.

The name of the library was changed from libtsk3 to libtsk

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/Other
Requires:       libtsk%sosuffix = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%setup -q

%build
export LIBS=' -lpthread -ldl'
%configure --disable-static

# remove rpath from libtool
# closed by tm
sed -i.rpath 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i.rpath 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

# clean unused-direct-shlib-dependencies
#sed -i -e 's! -shared ! -Wl,--as-needed\0!g' libtool

# export CFLAGS="%%{optflags}"
# export CXXFLAGS="%%{optflags}"
export LDFLAGS="-avoid-version -module"

make %{?_smp_mflags}

%install
%if 0%{?sles_version}
make install DESTDIR=%{buildroot} INSTALL="install -p"
%else
%make_install INSTALL="install -p"
%endif
find %{buildroot} -name '*.la' -exec rm -f {} ';'
mkdir -p %{buildroot}/%{_datadir}/sleuthkit
cp --archive bindings %{buildroot}/%{_datadir}/sleuthkit/bindings

%post -n libtsk%sosuffix -p /sbin/ldconfig

%postun -n libtsk%sosuffix -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc ChangeLog.txt NEWS.txt README.md licenses/*
# License is CPL 1.0 exept for some files.
%{_bindir}/blkcalc
%{_bindir}/blkcat
%{_bindir}/blkls
%{_bindir}/blkstat
#{_bindir}/disk_sreset
#{_bindir}/disk_stat
%{_bindir}/fcat
%{_bindir}/ffind
%{_bindir}/fiwalk
%{_bindir}/fls
%{_bindir}/fsstat
%{_bindir}/hfind
%{_bindir}/icat
%{_bindir}/ifind
%{_bindir}/ils
%{_bindir}/img_cat
%{_bindir}/img_stat
%{_bindir}/istat
%{_bindir}/jcat
%{_bindir}/jls
%{_bindir}/jpeg_extract
# This file is described as GPL in the doc
# But the license remains CPL in the source.
%{_bindir}/mactime
##
%{_bindir}/mmcat
%{_bindir}/mmls
%{_bindir}/mmstat
%{_bindir}/sigfind
%{_bindir}/sorter
%{_bindir}/usnjls

## This file is GPLv2+
%{_bindir}/srch_strings
#
%{_mandir}/man1/blkcalc.1*
%{_mandir}/man1/blkcat.1*
%{_mandir}/man1/blkls.1*
%{_mandir}/man1/blkstat.1*
#{_mandir}/man1/disk_sreset.1*
#{_mandir}/man1/disk_stat.1*
%{_mandir}/man1/fcat.1*
%{_mandir}/man1/ffind.1*
%{_mandir}/man1/fls.1*
%{_mandir}/man1/fsstat.1*
%{_mandir}/man1/hfind.1*
%{_mandir}/man1/icat.1*
%{_mandir}/man1/ifind.1*
%{_mandir}/man1/ils.1*
%{_mandir}/man1/img_cat.1*
%{_mandir}/man1/img_stat.1*
%{_mandir}/man1/istat.1*
%{_mandir}/man1/jcat.1*
%{_mandir}/man1/jls.1*
%{_mandir}/man1/mactime.1*
%{_mandir}/man1/mmcat.1*
%{_mandir}/man1/mmls.1*
%{_mandir}/man1/mmstat.1*
%{_mandir}/man1/sigfind.1*
%{_mandir}/man1/sorter.1*
%{_mandir}/man1/usnjls.1.gz
%dir %{_datadir}/tsk
%{_datadir}/tsk/sorter/

%{_bindir}/tsk_comparedir
%{_bindir}/tsk_gettimes
%{_bindir}/tsk_loaddb
%{_bindir}/tsk_recover
%{_mandir}/man1/tsk_comparedir.1.gz
%{_mandir}/man1/tsk_gettimes.1.gz
%{_mandir}/man1/tsk_loaddb.1.gz
%{_mandir}/man1/tsk_recover.1.gz

%files -n libtsk%sosuffix
%defattr(-,root,root,-)
# CPL and IBM
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root,-)
# CPL and IBM
%{_includedir}/tsk/
%{_libdir}/*.so
%{_datadir}/sleuthkit

%changelog
* Thu Sep 14 2017 Greg.Freemyer@gmail.com
- update to 4.4.2
  * usnjls tool for NTFS USN log (from noxdafox)
  * Added index to mime type column in DB
  * Use local SQLite3 if it exists (from uckelman-sf)
  * Blackboard Artifacts have a shortDescription metho
  * Fix for highest HFS+ inum lookup (from uckelman-sf)
  * Fix ISO9660 crash
  * various performance fixes and added thread safety checks
- add files related to the new usnjls tool
* Sat Feb 25 2017 Greg.Freemyer@gmail.com
- update to 4.4.0
  * Compiling in Windows now uses Visual Studio 2015
  * tsk_loaddb now adds new files for slack space
  and JNI was upgraded accordingly.
* Fri Jul 29 2016 Greg.Freemyer@gmail.com
- update to 4.3.0
  * PostgreSQL support (Windows only)
  * Support for virtual machine formats via libvmdk and libvhdi (Windows only)
  * Schema updates (data sources table, mime type, attributes store type)
  * tsk_img_open can take externally created TSK_IMG_INFO
  * New Release_ NoLibs Visual Studio target
  * Various bug fixes
* Wed Feb  3 2016 Greg.Freemyer@gmail.com
- upgrade to 4.2.0
  * ExFAT support added
  * New database schema
  * New Sqlite hash database
  * Added secondary hash database index
  * Various bug fixes
  * NTFS pays more attention to sequence and loads metadata only
  if it matches.
- README.txt renamed README.md
- patch sleuthkit-4.1.3-python-tsk.patch removed, now upstream
* Wed Aug 13 2014 Greg.Freemyer@gmail.com
- upgrade to 4.1.3
  * fixed bug that could crash UFS/ExtX in inode_lookup.
  * More bounds checking in ISO9660 code
  * Image layer bounds checking
  * Update version of SQLITE-JDBC
  * changed how java loads navite libraries
  * Config file for YAFFS2 spare area
  * New method in image layer to return names
  * Yaffs2 cleanup.
  * Escape all strings in SQLite database
  * SQlite code uses NTTFS sequence number to match parent IDs
  * FILE_NAME times in timelines
  * Cellebrite disk image auto-detect
  * 64-bit windows targets
  * Fixed bug with Sqlite code not using NTFS Sequence
  * Jar files have native libraries in them
- remove sleuthkit-4.1.0-UPSTREAM-crc.patch, now in upstream release
- add sleuthkit-4.1.3-python-tsk.patch, needed by python-tsk
* Tue Oct 15 2013 Greg.Freemyer@gmail.com
- remove BuildRequires libaff - The format never got popular, and libewf is now recommended
- libaff is being dropped from factory
* Sat Jun 22 2013 Greg.Freemyer@gmail.com
- this upgrade breaks most packages that build against sleuthkit-devel
- upgrade to 4.1.0
  * New Features in Core:
    Added YAFFS2 support (patch from viaForensics).
    Added Ext4 support (patch from kfairbanks)
  * Framework:
    Added Linux and MAC support.
    Added L01 support.
    Added APIs to find files by name, path and extension.
    Removed deprecated TskFile::getAttributes methods.
    moved code around for AutoBuild tool support.
  * Java Bindings:
    added DerivedFile datamodel support
    added a public method to Content to add ability to close() its tsk handle before the object is gc'd
    added faster skip() and random seek support to ReadContentInputStream
    refactored datamodel by pushing common methods up to AbstractFile
    fixed minor memory leaks
    improved regression testing framework for java bindings datamodel
  * -devel
    proper soname handling requires fixes in packages linking to libtsk
    /usr/include/tsk3 renamed /usr/include/tsk
    libtsk3-9.so renamed libtsk-10.so due to proper soname handling
    other include file changes
- rm fiwalk patch, now in upstream
- add crc.c patch, now in upstream git repo
- sortr renamed sorter by upstream
- upstream improved soname handling, reflect improvements
- add the java bindings to sleuthkit-devel (Packaging not well tested)
- resolves BNC#815061
* Sun Mar  3 2013 Greg.Freemyer@gmail.com
- Add obsoletes statement for fiwalk
- add patch to support "fiwalk -m"
* Wed Feb 13 2013 hpj@urpla.net
- Version 4.0.2
  New Features in Core:
    fiwalk is now included.
  Bug Fixes in Core:
    Fixed fcat to work on NTFS files (still doesn't support ADS though).
    Fixed HFS+ support in tsk_loaddb / SQLite -- root directory was not added.
    NTFS code now looks at all MFT entries when listing directory contents. It used to only look at unallocated entries for orphan files. This fixes an image that had allocated files missing from the directory b-tree.
    NTFS code uses sequence number when searching MFT entries for all files.
    Libewf detection code change to support v2 API more reliably (ID: 3596212).
    NTFS $SII code could crash in rare cases if $SDS was multiple of block size.
  Framework:
    Added new API to TskImgDB that returns the base name of an image.
    Numerous performance improvements to framework.
    Removed requirement in framework to specify module extension in pipeline configuration file.
    Added blackboard artifacts to represent both operating system and network service user accounts.
  Java Bindings
    More methods to query files
    Methods to get current directory when being added to DB.
    Modified class structure a bit
    More lazy loading for children / parents.
    Better exception throwing from C++
- Version 4.0.1
  New Features:
    More DOS partition types are displayed.
    Added fcat tool that takes in file name and exports content (equivalent to using ifind and icat together).
    performance improvements with FAT code (maps and dir_add)
    performance improvements with NTFS code (maps)
    added AONLY flag to block_walk
    Updated blkls and blkcalc to use AONLY flag -- MUCH faster.
  Bug Fixes:
    Fixed mactime issue where it could choose the wrong timezone that did not follow daylight savings times.
    Fixed file size of alternate data streams in framework.
    Incorporated memory leak fixes and raw device fixes from ADF Solutions.
* Tue Oct  2 2012 Greg.Freemyer@gmail.com
- Version 4.0.0
  - general release of the 4.0.0b1 beta release
  - only tested by upstream in windows
* Thu Sep  6 2012 Greg.Freemyer@gmail.com
- Version 4.0.0b1
  - Builds with libewf-20120813 (libewf v2)
  - drop sleuthkit-gcc47.patch: upstreamed
  4.0.0b1 has a lot of new features, including:
  . Framework with first set of basic modules (hash calculation, hash lookup, entropy calculation, RegRipper, ZIP file extraction, extraction via name signatures, etc.) -- Windows-only
  . Multithreaded support
  . C++ wrapper classes
  . JNI bindings and data model classes
  . All non-set times are displayed as 0 instead of 1970.
  . Only first file in split or E01 needs to be specified.
  . EnCase Hashset support in hash tools.
  . New table schema for loaddb database that supports more data types (carved, local files, etc.).
* Wed Apr 11 2012 dimstar@opensuse.org
- Add sleuthkit-gcc47.patch: Fix buffer overflow.
* Fri Oct 21 2011 Greg.Freemyer@gmail.com
- Add EnCase image support for reading
  - Source code support was already present, this just involved linking libewf into the build
* Fri Oct  7 2011 Greg.Freemyer@gmail.com
- VERSION 3.2.3
  New Features:
  - new TskAuto method (handleNotification()) that gets verbose messages that allow for debugging when the class makes decisions.
  - DOS partitions are loaded even if an extended partition fails to load
  - new TskAuto::findFilesInFs(TSK_FS_INFO *) method
  - Need to only specify first E01 file and the rest are found
  - Changed docs license to opensuse accepted one (by upstream)
  - Unicode conversion routines fix invalid UTF-16 text during conversion
  - Added '-d' to tsk_recover to specify directory to recover
  Bug Fixes:
  - Added check to fatfs_open to compare first sectors of FAT if we used backup boot sector and verify it is FAT32.
  - More checks to make sure that FAT short names are valid ASCII
  - 3406523: Mactime size sanity check
  - 3393960: hfind reading of Windows input file
  - 3316603: Error reading last blocks of RAW CD images
  - Fixed bugs in how directories and files were detected in TskAuto
* Thu Aug  4 2011 toganm@opensuse.org
- Update sleuthkit-3.2.2.tar.gz
  * cleaned spec
* Mon Sep 13 2010 toganm@dinamizm.com
- Reworking the spec file
* Mon Sep 13 2010 toganm@opensuse.org
-  Spec file corrections
* Mon Sep 13 2010 Togan Muftuoglu <toganm@opensuse.org> -3.1.3
- Adaptation of spec file from fedora project
- Update to 3.1.3
* Thu Apr 29 2010 Nicolas Chauvet <kwizart@fedoraproject.org> - 3.1.1-1
- Update to 3.1.1
* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild
* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild
  Tue Feb 10 2009 kwizart < kwizart at gmail.com > - 3.0.1-1
- Update to 3.0.1 (final)
  Tue Oct 28 2008 kwizart < kwizart at gmail.com > - 3.0.0-1
- Update to 3.0.0 (final)
  Fri Oct  3 2008 kwizart < kwizart at gmail.com > - 3.0.0-0.1.b4
- Update to 3.0.0b4
  Tue Jun 17 2008 kwizart < kwizart at gmail.com > - 2.52-1
- Update to 2.52
- Remove merged patches
- Remove clean unused-direct-shlib-dependencies
- Fix rpath at source.
- Sort license within the spec
- Move configure.ac to pkg-config detection
- Remove Perl-Date-Manip installation
  Tue Mar 18 2008 kwizart < kwizart at gmail.com > - 2.51-1
- Update to 2.51
- Add libewf/afflib BR
- Requires mac-robber external package.
- Remove internal perl-Date-Manip.
  Fri Dec 28 2007 kwizart < kwizart at gmail.com > - 2.10-1
- Update to 2.10
  Mon Oct 29 2007 kwizart < kwizart at gmail.com > - 2.09-1
- Initial package for Fedora
  (inspired from Oden Eriksson mdk spec).
